========
MaFreDo
========

Marine Frequency Domain


Description
===========

A set of tools for working with frequency domain data for marine applications.

-  Rao    : A class for Rao data with methods for interpolation
-  Hyddb1 : A class for first order hydrodynamic data (added mass, damping, wave-forces)

Inspired by and build to work with:

- capytaine (BEM) [https://github.com/mancellin/capytaine]
- wavespectra ([https://github.com/metocean/wavespectra])
- DAVE (General marine modeller) [https://open-ocean.org/DAVE]

Note
====


